'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _jsonp = require('./../jsonp');

var _jsonp2 = _interopRequireDefault(_jsonp);

var _DB = require('./../DB');

var _DB2 = _interopRequireDefault(_DB);

var _Device = require('./../Device');

var _Device2 = _interopRequireDefault(_Device);

var _instance = require('./../Toast/instance.js');

var _instance2 = _interopRequireDefault(_instance);

var _instance3 = require('./../Alert/instance.js');

var _instance4 = _interopRequireDefault(_instance3);

var _instance5 = require('./../Loading/instance.js');

var _instance6 = _interopRequireDefault(_instance5);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

if (!window._seeds_lang) window._seeds_lang = {}; // 国际化数据

var Bridge = {
  /**
  * 基础功能:start
  */
  debug: false,
  // 拨打电话
  tel: function tel(number) {
    if (_Device2.default.device === 'pc') {
      this.showToast(window._seeds_lang['hint_only_mobile'] || '此功能仅可在手机中使用');
      return;
    }
    if (isNaN(number)) return;
    window.location.href = 'tel:' + number;
  },
  // 弹出toast
  toast: null,
  showToast: function showToast(msg) {
    var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    if (!msg) return;
    if (!this.toast) {
      // 提示错误
      this.toast = new _instance2.default({
        parent: document.body,
        maskClass: 'mask toast-mask' + (params.mask === false ? ' toast-propagation' : ''),
        toastClass: 'toast ' + (params.position ? params.position : 'middle'),
        icon: params.icon || '',
        html: msg,
        delay: params.delay || 2000
      });
    } else {
      this.toast.setHTML(msg);
      this.toast.setMaskClassName('mask toast-mask' + (params.mask === false ? ' toast-propagation' : ''));
      this.toast.setToastClassName('toast ' + (params.position ? params.position : 'middle'));
      this.toast.setIcon(params.icon || '');
      this.toast.setDelay(params.delay || 2000);
    }
    this.toast.show();
    if (params.success) {
      setTimeout(function () {
        params.success();
      }, params.delay ? Math.round(params.delay / 2) : 1000);
    }
  },
  // 弹出loading
  loading: null,
  showLoading: function showLoading() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    if (!this.loading) {
      this.loading = new _instance6.default({
        caption: params.caption || window._seeds_lang['loading'] || '正在加载...',
        type: params.type,
        icon: params.icon || '',
        maskCss: params.css || null
      });
    } else {
      if (params.caption) this.loading.setCaption(params.caption);
      if (params.type) this.loading.setType(params.type);
      if (params.css) this.loading.setMaskCss(params.css);
      if (params.icon) this.toast.setIcon(params.icon || '');
      if (params.mask) this.loading.setMaskClassName('mask loading-mask ' + (params.mask === false ? ' loading-propagation' : ''));
    }
    this.loading.show();
  },
  hideLoading: function hideLoading() {
    if (!this.loading) {
      this.toast.showToast(window._seeds_lang['hint_hideloading_after_showloading'] || 'showLoading后才能hideLoading');
    } else {
      this.loading.hide();
    }
  },
  // 弹出Alert
  alert: null,
  showAlert: function showAlert(msg) {
    var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    if (!this.alert) {
      this.alert = new _instance4.default(_extends({}, params, {
        html: msg,
        onClickSubmit: function onClickSubmit(e) {
          if (params.success) params.success(e);else e.hide();
        }
      }));
    } else {
      if (params) {
        this.alert.reset();
        for (var n in params) {
          this.alert.params[n] = params[n];
        }
        this.alert.updateDOM();
        this.alert.setHTML(msg);
      }
    }
    this.alert.show();
  },
  // 弹出Confirm
  confirm: null,
  showConfirm: function showConfirm(msg) {
    var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    if (!this.confirm) {
      this.confirm = new _instance4.default(_extends({}, params, {
        html: msg,
        onClickSubmit: function onClickSubmit(e) {
          if (params.success) params.success(e);
        },
        onClickCancel: function onClickCancel(e) {
          if (params.fail) params.fail(e);else e.hide();
        }
      }));
    } else {
      if (params) {
        this.confirm.reset();
        for (var n in params) {
          this.confirm.params[n] = params[n];
        }
        this.confirm.updateDOM();
        if (params.success) this.confirm.setOnClickSubmit(params.success);
        if (params.fail) this.confirm.setOnClickCancel(params.fail);
      }
      this.confirm.setHTML(msg);
    }
    this.confirm.show();
  },
  /**
    * 百度地图:获取当前位置名称,只支持gcj02
    * @param {Object} params: {longitude: '', latitude: '', success: fn, fail: fn}
    * @returns {Object} {address:'地址全称'}
    */
  getAddress: function getAddress() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var url = 'https://api.map.baidu.com/geocoder/v2/?callback=renderReverse&location=' + params.latitude + ',' + params.longitude + '&output=json&pois=1&ak=IlfRglMOvFxapn5eGrmAj65H&ret_coordtype=gcj02ll';
    (0, _jsonp2.default)(url, null, function (err, data) {
      if (err) {
        if (params.fail) params.fail({ errMsg: 'getAddress:' + (window._seeds_lang['hint_address_failed'] || '获取地址失败, 请稍后重试') + err });
      } else {
        var addrs = {};
        if (data.result && data.result.formatted_address) {
          addrs.address = data.result.formatted_address;
          if (params.success) params.success(addrs);
        } else {
          if (params.fail) params.fail({ errMsg: 'getAddress:' + (window._seeds_lang['hint_address_failed'] || '获取地址失败, 请稍后重试') });
        }
      }
    });
  },
  /**
    * 百度地图:获得天气
    * @param {Object} params: {location: 'lng,lat|lng,lat|lng,lat' | '北京市|上海市', success: fn, fail: fn}
    * @returns {Object} 天气信息results
    */
  getWeather: function getWeather() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var url = 'http://api.map.baidu.com/telematics/v3/weather?location=' + (params.location || '南京市') + '&output=json&ak=IlfRglMOvFxapn5eGrmAj65H';
    (0, _jsonp2.default)(url, null, function (err, data) {
      if (err) {
        if (params.fail) params.fail({ errMsg: 'getWeather:' + (window._seeds_lang['hint_weather_failed'] || '获取天气失败, 请稍后重试') + err });
      } else {
        if (data.results && data.results.length) {
          if (params.success) params.success(data.results);
        } else {
          if (params.fail) params.fail({ errMsg: 'getWeather:' + (window._seeds_lang['hint_weather_failed'] || '获取天气失败, 请稍后重试') });
        }
      }
    });
  },
  // 客户端默认返回控制
  back: function back(argHistory, argBackLvl) {
    // 返回操作对象与返回层级
    var _history = window.history;
    if (argHistory && argHistory.go) _history = argHistory;
    var _backLvl = argBackLvl || -1;

    // 返回类型
    var isFromApp = _Device2.default.getUrlParameter('isFromApp', location.search) || '';
    if (isFromApp === '1') {
      // 关闭当前页面
      try {
        Bridge.closeWindow();
      } catch (error) {
        console.log(error);
      }
    } else if (isFromApp === 'home') {
      // 返回首页
      try {
        Bridge.goHome();
      } catch (error) {
        console.log(error);
      }
    } else if (isFromApp === 'confirm') {
      // 提示后返回上一页
      Bridge.showConfirm(Bridge.confirmCaption || window._seeds_lang['confirm_quit_page'] || '您确定要离开此页面吗?', {
        success: function success(e) {
          e.hide();
          _history.go(_backLvl);
        }
      });
    } else if (isFromApp === 'confirm-close') {
      // 提示后关闭当前页面
      Bridge.showConfirm(Bridge.confirmCaption || window._seeds_lang['confirm_quit_page'] || '您确定要离开此页面吗?', {
        success: function success(e) {
          e.hide();
          Bridge.closeWindow();
        }
      });
    } else if (isFromApp === 'custom') {
      console.log('自定义');
    } else {
      // 返加上一页
      _history.go(_backLvl);
    }
  },
  // 判断是否是主页
  isHomePage: function isHomePage(callback) {
    this.invoke('isHomePage', null, function (data) {
      if (data.result.toString() === '1') {
        callback(true);
      } else {
        callback(false);
      }
    });
  },
  // 获得版本信息
  getAppVersion: function getAppVersion() {
    var ua = navigator.userAgent.toLowerCase();
    var verExp = ua.match(/dinghuoappversion\/.{0,}(\d+\.\d+\.\d+)/);
    if (verExp && verExp[1]) return verExp[1].trim();
    return '';
  },
  // 去首页
  goHome: function goHome(callback) {
    this.invoke('goHome', null, callback);
  },
  // 退出到登陆页面
  logOut: function logOut() {
    this.invoke('logOut');
  },
  // 打开新的窗口
  openWindow: function openWindow(params, callback) {
    this.invoke('openWindow', params, callback);
  },
  // 关闭当前窗
  closeWindow: function closeWindow(callback) {
    this.invoke('closeWindow', null, callback);
  },
  // 客户端添加返回绑定
  addBackPress: function addBackPress(callback) {
    try {
      this.setBackEnable(true);
      window.addEventListener('onBackPress', callback || this.back);
      // ios客户端返回按钮绑定(ios不支持onBackPress)
      this.addIosBackPress(callback);
    } catch (error) {
      console.log(error);
    }
  },
  // 客户端移除返回绑定
  removeBackPress: function removeBackPress(callback) {
    try {
      this.setBackEnable(false);
      window.removeEventListener('onBackPress', callback || this.back);
    } catch (error) {
      console.log(error);
    }
  },
  /**
   * 基础功能:end
   */

  /**
   * 定制功能
   */
  platform: 'dinghuo',
  config: function config() {
    // 返回物理按键绑定
    this.addBackPress();
    _DB2.default.setSession('bridge_isready', '1');
    this.registerHandler(['getGoodsByApp', 'getCartGoodsByApp', 'onBackPress', 'setOnlineByApp']);
  },
  // 公共方法，通过桥接调用原生方法公共入口
  invoke: function invoke(name, param, callback) {
    if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
      /* 判断iPhone|iPad|iPod|iOS */
      /* eslint-disable */
      this.setup(function (bridge) {
        bridge.callHandler(name, param, function (response) {
          if (callback) {
            try {
              callback(JSON.parse(response));
            } catch (e) {
              callback(response);
            }
          }
        });
      });
      /* eslint-enable */
    } else if (/(Android)/i.test(navigator.userAgent)) {
      /* 判断Android */
      // 注册分类页面事件
      if (window.WebViewJavascriptBridge) {
        window.WebViewJavascriptBridge.callHandler(name, param && JSON.stringify(param), function (response) {
          if (callback) {
            try {
              callback(JSON.parse(response));
            } catch (e) {
              callback(response);
            }
          }
        });
      } else {
        document.addEventListener('WebViewJavascriptBridgeReady', function () {
          window.WebViewJavascriptBridge.callHandler(name, param && JSON.stringify(param), function (response) {
            if (callback) {
              try {
                callback(JSON.parse(response));
              } catch (e) {
                callback(response);
              }
            }
          });
        }, false);
      }
    }
  },
  setup: function setup(callback) {
    /* eslint-disable */
    if (window.WebViewJavascriptBridge) {
      return callback(WebViewJavascriptBridge);
    }
    if (window.WVJBCallbacks) {
      return window.WVJBCallbacks.push(callback);
    }
    window.WVJBCallbacks = [callback];
    var WVJBIframe = document.createElement('iframe');
    WVJBIframe.style.display = 'none';
    WVJBIframe.src = 'https://__bridge_loaded__';
    document.documentElement.appendChild(WVJBIframe);
    setTimeout(function () {
      document.documentElement.removeChild(WVJBIframe);
    }, 0);
    /* eslint-enable */
  },

  // 注册事件
  registerHandler: function registerHandler(events) {
    if (typeof window !== 'undefined') {
      if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
        /* 判断iPhone|iPad|iPod|iOS */
        /* eslint-disable */
        this.setup(function (bridge) {
          events.forEach(function (eventName) {
            bridge.registerHandler(eventName, function () {
              var event = new CustomEvent(eventName);
              // 分发事件
              window.dispatchEvent(event);
            });
          });
        });
        /* eslint-enable */
      } else if (/(Android)/i.test(navigator.userAgent)) {
        /* 判断Android */
        // 注册分类页面事件
        if (window.WebViewJavascriptBridge) {
          events.forEach(function (eventName) {
            window.WebViewJavascriptBridge.registerHandler(eventName, function () {
              var event = new CustomEvent(eventName);
              // 分发事件
              window.dispatchEvent(event);
            });
          });
        } else {
          document.addEventListener('WebViewJavascriptBridgeReady', function () {
            events.forEach(function (eventName) {
              window.WebViewJavascriptBridge.registerHandler(eventName, function () {
                var event = new CustomEvent(eventName);
                // 分发事件
                window.dispatchEvent(event);
              });
            });
          }, false);
        }
      }
    }
  },
  /**
    * 支付宝支付
    * @param {Object} params {orderInfo: ''}
    * @param {Function} callback
    * @callback(result) {Object} {code: "0", message: "支付成功"}|{code: "-1", message: "支付失败"}|{code: "-1", message: "数据解析异常"}
    */
  alipay: function alipay(params, callback) {
    this.invoke('alipay', params, callback);
  },
  /**
    * 商联支付
    * @param {Object} params {appKey:'', dealerCode:'', orderId:'', payAmount:''}
    * @param {Function} callback 回调
    */
  slopenpay: function slopenpay(params, callback) {
    this.invoke('slopenpay', params, callback);
  },
  /**
    * 大华捷通支付
    * @param {Object} params {payChannel:'UPPay 云闪付  WXPay微信支付 AliPay 支付宝支付', payData:'服务端获取'}
    * @param {Function} callback 回调
    */
  qmfpay: function qmfpay(params, callback) {
    // resultCode:
    // 0000 支付请求发送成功,商户订单是否成功支付应该以商户后台收到支付结果
    // 1000 用户取消支付
    // 1001 参数错误
    // 1002 网络连接错误
    // 1003 支付客户端未安装
    // 2001 订单处理中，支付结果未知(有可能已经支付成功)，请通过后台接口查询订单状态
    // 2002 订单号重复
    // 2003 订单支付失败
    // 9999 其他支付错误
    // 5004 版本过低
    if (Bridge.getAppVersion() < '2.3.6') {
      callback({ resultCode: '5004', resultInfo: '{"resultMsg":"请安装2.3.6以上版本"}' });
      return;
    }
    this.invoke('qmfpay', params, callback);
  },
  /**
    * 修改原生标题
    * @param {Object} params {title: '自定义标题'}
    * @param {Function} callback 回调
    */
  setTitle: function setTitle(params, callback) {
    this.invoke('setTitle', params, callback);
  },
  /**
    * ios绑定左上角返回按钮
    * @param {Object} params {title: '自定义标题'}
    * @param {Function} callback 回调
    */
  onHistoryBack: function onHistoryBack(callback) {
    this.invoke('onHistoryBack', null, callback);
  },
  // ios客户端返回按钮绑定, ios不支持addBackPress
  addIosBackPress: function addIosBackPress(callback) {
    var _this = this;

    this.onHistoryBack(function () {
      if (callback) callback();else if (_this.back) _this.back();
      _this.addIosBackPress(callback);
    });
  },
  /**
    * 分享文本
    * @param {Object} params
    * {
    * title: '标题(仅ios支持)',
    * desc: '副标题(仅ios支持)',
    * link: '链接(仅ios支持)',
    * text: '文本(安卓只支持发送文本)',
    * }
    * @param {Function} callback 回调
    */
  shareText: function shareText(params, callback) {
    this.invoke('shareText', params, callback);
  },
  /**
    * 获取订货包名
    * @param {Function} callback({result: 'cn.com.wq.ordergoods'}), ios包名cn.com.wq.ordergoods, andriod包名com.waiqin365.dhcloud
    */
  getIdentification: function getIdentification(callback) {
    if (Bridge.getAppVersion() < '2.3.6') {
      callback({});
      return;
    }
    this.invoke('getIdentification', null, callback);
  },
  /* -----------------------------------------------------
    文件操作
  ----------------------------------------------------- */
  /* 文件是否存在
  isExistsFile({
    "fileName": "ss.txt",
    "size": 200
  }, (result) => {
  // 返回格式 {{"isExists":"","filePath":"","fileName":""}，isExists:'0'不存在，'1'存在
  })
  */
  isExistsFile: function isExistsFile(params, callback) {
    this.invoke('isExistsFile', params, callback);
  },
  /* 附件下载
  downloadFile({
    "id": "id",
    "fileName": "ss.txt",
    "downloadUrl": "http://...",
    "size": 200
  }, (result) => {
  // 返回格式 {{"code":"","filePath":"","message":""}，code:'0'失败，'1'成功，message失败原因
  }) */
  downloadFile: function downloadFile(params, callback) {
    this.invoke('downloadFile', params, callback);
  },
  /* 附件打开
  openFile（{
    "filePath": ""
  }, (result) => {
  // 返回格式 {{"code":"","message":""}，code:'0'失败，'1'成功，message失败原因
  }） */
  openFile: function openFile(params, callback) {
    this.invoke('openFile', params, callback);
  },
  /* -----------------------------------------------------
    扫描二维码并返回结果
    @return {resultStr:''}
  ----------------------------------------------------- */
  scanQRCode: function scanQRCode(params) {
    this.invoke('scanQRCode', null, params.success);
  },
  /**
    * 获取当前地理位置
    * @param {Object} params
    * params: {
    * type {String}: 'wgs84'|'gcj02'坐标类型微信默认使用国际坐标'wgs84',
    * cache {Number}: 默认60秒缓存防重复定位
    * }
    * @returns {Object} {latitude: '纬度', longitude: '经度', speed:'速度', accuracy:'位置精度'}
    */
  getLocation: function getLocation() {
    var _this2 = this;

    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    // 先从cookie中读取位置信息
    var appLocation = _DB2.default.getCookie('app_location');
    if (appLocation === 'undefined') {
      _DB2.default.removeCookie('app_location');
      appLocation = '';
    }
    try {
      if (appLocation) appLocation = JSON.parse(appLocation);
    } catch (error) {
      appLocation = '';
    }
    if (appLocation) {
      if (params.success) params.success(appLocation);
      return;
    }

    // 调用定位
    if (this.locating) return;
    this.locating = true;
    console.log('调用定位...');
    this.invoke('getLocation', 'gcj02', function (res) {
      _this2.locating = false;
      if (res && res.latitude) {
        // 将位置信息存储到cookie中60秒
        if (params.cache) _DB2.default.setCookie('app_location', JSON.stringify(res), params.cache || 60);
        if (params.success) params.success(res);
      } else {
        if (params.fail) params.fail({ errMsg: 'getLocation:定位失败,请检查订货365定位权限是否开启' });else Bridge.showToast('定位失败,请检查订货365定位权限是否开启', { mask: false });
      }
    });
  },
  /* -----------------------------------------------------
    获取当前网络状态
    @return {networkType:'返回网络类型2g，3g，4g，wifi'}
  ----------------------------------------------------- */
  getNetworkType: function getNetworkType(callback) {
    this.invoke('getNetworkType', null, callback);
  },
  /**
    * 拍照、本地选图
    * @param {Object} params
    * {
    * sourceType:['album:相册', 'camera:拍照'],
    * sizeType:['original:原图', 'compressed:压缩'],
    * count:'最大张数',
    * success({localIds:['LocalResource://imageid'+id]})
    * }
    */
  chooseImage: function chooseImage(params) {
    this.invoke('chooseImage', params, function (res) {
      res.localIds = res.localIds.map(function (id) {
        return 'LocalResource://imageid' + id;
      });
      if (params.success) params.success(res);
    });
  },
  /**
    * 拍照、本地选图
    * @param {Object} params
    * {
    * dir:'',
    * localIds:['LocalResource://imageid' + id],
    * tenantId: 'ios必传'
    * }
    */
  uploadImage: function uploadImage() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    if (!params.dir) {
      Bridge.showToast(window._seeds_lang['hint_upload_image_must_dir'] || '没有上传目录', { mask: false });
      return;
    }
    if (!params.localIds || Object.isEmptyObject(params.localIds)) {
      Bridge.showToast(window._seeds_lang['hint_upload_image_must_localIds'] || '没有上传图片地址', { mask: false });
      return;
    }
    if (!params.tenantId) {
      Bridge.showToast(window._seeds_lang['hint_upload_image_must_tenantId'] || '没有上传企业id', { mask: false });
      return;
    }
    // ios上传不能包含'LocalResource://imageid'
    // if (/cpu iphone os (.*?) like mac os/.test(navigator.userAgent.toLowerCase())) {
    //   params.localIds = params.localIds.map(function (localId) {
    //     return localId.replace(new RegExp('LocalResource://imageid'), '')
    //   })
    // }
    params.localIds = params.localIds.map(function (localId) {
      return localId.replace(new RegExp('LocalResource://imageid'), '');
    });
    // 格式化params
    var uploadParams = {
      localIds: params.localIds,
      uploadDir: params.dir
    };
    if (params.tenantId) uploadParams.tenantId = params.tenantId;
    if (params.isAI) uploadParams.isAI = params.isAI;
    this.invoke('uploadImage', uploadParams);
  },
  /**
    * 图片预览
    * @param {Object} params
    * {
    * urls:['本地照片需要加上LocalResource://imageid'],
    * current:'当前显示图片地址',
    * index:'当前显示图片索引'
    * }
    */
  previewImage: function previewImage(params) {
    if (!params.urls || !params.urls.length) {
      Bridge.showToast(window._seeds_lang['hint_preview_image_must_urls'] || '没有预览图片地址', { mask: false });
      return;
    }
    this.invoke('previewImage', params);
  },
  /* -----------------------------------------------------
    监听/取消监听物理返回事件(仅android)
    @params true:监听 | false:取消监听
  ----------------------------------------------------- */
  setBackEnable: function setBackEnable(flag) {
    if (/(Android)/i.test(navigator.userAgent)) {
      /* 判断Android */
      this.invoke('setBackEnable', flag);
    }
  },
  // 获取图片前缀
  getImagePrefix: function getImagePrefix() {
    return 'LocalResource://imageid';
  },
  // 下载图片
  downloadImage: function downloadImage() {},
  // 分享给朋友
  onMenuShareAppMessage: function onMenuShareAppMessage() {},
  // 分享到朋友圈
  onMenuShareTimeline: function onMenuShareTimeline() {},
  // 获取登陆信息
  loginInfo: function loginInfo(callback) {
    this.invoke('getLoginInfo', null, callback);
  },
  // 根据key获取登陆信息
  getLoginInfo: function getLoginInfo(key, callback) {
    this.loginInfo(function (result) {
      callback(result[key]);
    });
  },

  // 获取系统参数
  systemParameter: function systemParameter(callback) {
    this.invoke('getSystemParameter', null, callback);
  },

  // 修改原生角标
  changeBadgeNum: function changeBadgeNum(count) {
    this.invoke('setBadgeNum', { key: count });
  },

  /* 封装图片控件,使用示例见ImgUploader组件
  bridge.Image({
    onChooseSuccess: function (imgMap) {},
  })
  */
  Image: function Image() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var s = this;
    var msg = '';
    // 选择照片
    s.choose = function () {
      var args = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      var option = {
        enableSafe: args.enableSafe || false, // 安全上传,第次只能传一张
        max: args.max || 5,
        currentCount: args.currentCount || 0,
        sourceType: args.sourceType || ['album', 'camera'],
        sizeType: args.sizeType || ['original', 'compressed'],
        chooseOptions: args.chooseOptions || {}
        /* watermark: {
          orderNo: 'xx', // 编号
          submitName: 'xx', // 提交人
          customerName: 'xx', // 客户
          cmLocation: '118.730515, 31.982473', // 位置算偏差
          isWaterMark: '1', // 是否启用水印
        } */
      };var count = option.max - option.currentCount;
      if (count <= 0) {
        msg = (window._seeds_lang['hint_max_upload'] || '最多只能传') + option.max + (window._seeds_lang['photos'] || '张照片');
        Bridge.showToast(msg);
        return;
      }
      // 如果设置了安全上传,则每次只允许上传一张
      if (option.enableSafe) count = 1;
      Bridge.chooseImage(Object.assign({
        count: count, // 默认5
        sizeType: option.sizeType, // 可以指定是原图还是压缩图，默认二者都有
        sourceType: option.sourceType, // 可以指定来源是相册还是相机，默认二者都有camera|album
        success: function success(res) {
          var imgMap = {};
          for (var i = 0, localId; localId = res.localIds[i++];) {
            // eslint-disable-line
            imgMap[localId] = {
              serverId: '',
              sourceType: JSON.stringify(option.sourceType) === JSON.stringify(['camera']) ? 'camera' : 'album'
            };
          }
          if (params.onChooseSuccess) params.onChooseSuccess(imgMap, res);
        }
      }, option.chooseOptions));
    };
  }
};

exports.default = Bridge;
module.exports = exports['default'];